@@ -28,11 +28,11 @@ options:
   limit:
     description:
     - Limit query parameter.
-    type: str
+    type: int
   offset:
     description:
     - Offset query parameter.
-    type: str
+    type: int
   nameList:
     description:
     - NameList query parameter.
@@ -58,8 +58,8 @@ options:
     - Id path parameter. Module id.
     type: str
 requirements:
-- dnacentersdk >= 2.5.4
-- python >= 3.5
+- dnacentersdk >= 2.6.0
+- python >= 3.9
 seealso:
 - name: Cisco DNA Center documentation for Devices GetModuleInfoById
   description: Complete reference of the GetModuleInfoById API.
@@ -90,8 +90,8 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
     deviceId: string
-    limit: string
-    offset: string
+    limit: 0
+    offset: 0
     nameList: []
     vendorEquipmentTypeList: []
     partNumberList: []
