@@ -240,7 +240,7 @@ class VMWareInventory(object):
         if PY3:
             config = configparser.ConfigParser()
         else:
-            config = configparser.SafeConfigParser()
+            config = configparser.ConfigParser()
 
         # where is the config?
         vmware_ini_path = os.environ.get('VMWARE_INI_PATH', defaults['vmware']['ini_path'])
@@ -283,7 +283,7 @@ class VMWareInventory(object):
         self.maxlevel = int(config.get('vmware', 'max_object_level'))
         self.debugl('max object level is %s' % self.maxlevel)
         self.lowerkeys = config.get('vmware', 'lower_var_keys')
-        if type(self.lowerkeys) != bool:
+        if not isinstance(self.lowerkeys, bool):
             if str(self.lowerkeys).lower() in ['yes', 'true', '1']:
                 self.lowerkeys = True
             else:
@@ -349,7 +349,7 @@ class VMWareInventory(object):
         if self.validate_certs and hasattr(ssl, 'SSLContext'):
             context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
             context.verify_mode = ssl.CERT_REQUIRED
-            context.check_hostname = True
+            context.check_hostname = True  # noqa  # pylint: disable=assigning-non-slot
             kwargs['sslContext'] = context
         elif self.validate_certs and not hasattr(ssl, 'SSLContext'):
             sys.exit('pyVim does not support changing verification mode with python < 2.7.9. Either update '
@@ -357,7 +357,7 @@ class VMWareInventory(object):
         elif not self.validate_certs and hasattr(ssl, 'SSLContext'):
             context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
             context.verify_mode = ssl.CERT_NONE
-            context.check_hostname = False
+            context.check_hostname = False  # noqa  # pylint: disable=assigning-non-slot
             kwargs['sslContext'] = context
         elif not self.validate_certs and not hasattr(ssl, 'SSLContext'):
             # Python 2.7.9 < or RHEL/CentOS 7.4 <
@@ -428,7 +428,7 @@ class VMWareInventory(object):
 
         return instance_tuples
 
-    def instances_to_inventory(self, instances):
+    def instances_to_inventory(self, instances):  # noqa  # pylint: disable=too-complex
         ''' Convert a list of vm objects into a json compliant inventory '''
         self.debugl('re-indexing instances based on ini settings')
         inventory = VMWareInventory._empty_inventory()
@@ -564,7 +564,7 @@ class VMWareInventory(object):
             mapping[k] = newkey
         return mapping
 
-    def facts_from_proplist(self, vm):
+    def facts_from_proplist(self, vm):  # noqa  # pylint: disable=too-complex
         '''Get specific properties instead of serializing everything'''
 
         rdata = {}
@@ -687,7 +687,7 @@ class VMWareInventory(object):
 
         return rdata
 
-    def _process_object_types(self, vobj, thisvm=None, inkey='', level=0):
+    def _process_object_types(self, vobj, thisvm=None, inkey='', level=0):  # noqa  # pylint: disable=too-complex
         ''' Serialize an object '''
         rdata = {}
 
