@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_fmg_variable_dynamicmapping
-short_description: no description
+short_description: Fmg variable dynamic mapping
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -118,7 +118,7 @@ EXAMPLES = '''
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: Fmg variable dynamic mapping
       fortinet.fortimanager.fmgr_fmg_variable_dynamicmapping:
         # bypass_validation: false
         workspace_locking_adom: <value in [global, custom adom including root]>
